@@ -42,49 +42,54 @@ class __TwigTemplate_ccc3f72ab858d105a4306f762fae357a extends Template
         // line 1
         yield "<!DOCTYPE html>
 <html>
-
+";
+        // line 3
+        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Default/head.html.twig", ["headerTitle" => ((        $this->unwrap()->hasBlock("headerTitle", $context, $blocks)) ? (        $this->unwrap()->renderBlock("headerTitle", $context, $blocks)) : (((        // line 4
+array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::default((isset($context["headerTitle"]) || array_key_exists("headerTitle", $context) ? $context["headerTitle"] : (function () { throw new RuntimeError('Variable "headerTitle" does not exist.', 4, $this->source); })()), "")) : ("")))), "pageTitle" => ((        $this->unwrap()->hasBlock("pageTitle", $context, $blocks)) ? ("Cause Buzz") : ("Cause Buzz"))]);
+        // line 7
+        yield "
     <body class=\"header-fixed\">
         <section id=\"app-wrapper\">
             ";
-        // line 6
+        // line 10
         yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputScripts("bodyOpen");
         yield "
 
             ";
-        // line 8
+        // line 12
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Notification/flashes.html.twig");
         yield "
             ";
-        // line 9
+        // line 13
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Menu/quick_help.html.twig");
         yield "
             ";
-        // line 10
+        // line 14
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Modal/tokens_help.html.twig");
         yield "
             ";
-        // line 11
+        // line 15
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Modal/keyboard_shortcuts.html.twig");
         yield "
             ";
-        // line 12
+        // line 16
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Modal/search_commands.html.twig");
         yield "
             ";
-        // line 13
+        // line 17
         yield $this->env->getRuntime('Symfony\Bridge\Twig\Extension\HttpKernelRuntime')->renderFragment(Symfony\Bridge\Twig\Extension\HttpKernelExtension::controller("Mautic\\CoreBundle\\Controller\\DefaultController::globalSearchAction"));
         yield "
 
             <aside class=\"app-sidebar sidebar-left\">
                 ";
-        // line 16
+        // line 20
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/LeftPanel/index.html.twig");
         yield "
             </aside>
 
             <header id=\"app-header\" class=\"navbar\">
                 ";
-        // line 20
+        // line 24
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Default/navbar.html.twig");
         yield "
             </header>
@@ -94,11 +99,11 @@ class __TwigTemplate_ccc3f72ab858d105a4306f762fae357a extends Template
                 <div class=\"container-fluid\">
                     <div class=\"row\">
                         <div class=\"col-xs-6 text-muted\">© ";
-        // line 27
+        // line 31
         yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Twig\Extension\CoreExtension']->formatDate("now", "Y"), "html", null, true);
         yield " Cause Buzz. Alle Rechte vorbehalten.</div>
                         <div class=\"col-xs-6 text-muted text-right small\">v";
-        // line 28
+        // line 32
         yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Mautic\CoreBundle\Twig\Extension\VersionExtension']->getVersion(), "html", null, true);
         yield "</div>
                     </div>
@@ -108,17 +113,17 @@ class __TwigTemplate_ccc3f72ab858d105a4306f762fae357a extends Template
 
             <section id=\"app-content\">
                 ";
-        // line 35
+        // line 39
         yield from $this->unwrap()->yieldBlock('_content', $context, $blocks);
-        // line 38
+        // line 42
         yield "            </section>
 
             <script>
                 Mautic.onPageLoad('body');
                 ";
-        // line 42
-        if ((CoreExtension::getAttribute($this->env, $this->source, (isset($context["app"]) || array_key_exists("app", $context) ? $context["app"] : (function () { throw new RuntimeError('Variable "app" does not exist.', 42, $this->source); })()), "environment", [], "any", false, false, false, 42) === "dev")) {
-            // line 43
+        // line 46
+        if ((CoreExtension::getAttribute($this->env, $this->source, (isset($context["app"]) || array_key_exists("app", $context) ? $context["app"] : (function () { throw new RuntimeError('Variable "app" does not exist.', 46, $this->source); })()), "environment", [], "any", false, false, false, 46) === "dev")) {
+            // line 47
             yield "                mQuery( document ).ajaxComplete(function(event, XMLHttpRequest, ajaxOption){
                     if(XMLHttpRequest.responseJSON && typeof XMLHttpRequest.responseJSON.ignore_wdt == 'undefined' && XMLHttpRequest.getResponseHeader('x-debug-token')) {
                         if (mQuery('[class*=\"sf-tool\"]').length) {
@@ -132,17 +137,54 @@ class __TwigTemplate_ccc3f72ab858d105a4306f762fae357a extends Template
                 });
                 ";
         }
-        // line 55
+        // line 59
         yield "            </script>
+            <script>
+                document.addEventListener('DOMContentLoaded', function () {
+
+                    const BRAND = 'Cause Buzz';
+
+                    function updateTitleSafe() {
+
+                        // Delay ensures Mautic finished updating title
+                        setTimeout(function () {
+
+                            var current = document.title || '';
+
+                            // Remove \"Mautic\"
+                            current = current.replace(/\\|\\s*Mautic\$/i, '').trim();
+
+                            // Remove duplicate brand
+                            current = current.replace(new RegExp('\\\\|\\\\s*' + BRAND + '\$', 'i'), '').trim();
+
+                            // If empty
+                            if (!current || current === 'Mautic') {
+                                document.title = BRAND;
+                                return;
+                            }
+
+                            document.title = current + ' | ' + BRAND;
+
+                        }, 0);
+                    }
+
+                    // Initial load
+                    updateTitleSafe();
+
+                    // Safe Mautic SPA hook
+                    document.addEventListener('mautic:page:load', updateTitleSafe);
+
+                });
+            </script>
 
             ";
-        // line 57
+        // line 98
         yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputScripts("bodyClose");
         yield "
             ";
-        // line 58
+        // line 99
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/modal.html.twig", ["id" => "MauticSharedModal", "footerButtons" => true]);
-        // line 61
+        // line 102
         yield "
         </section>
     </body>
@@ -152,14 +194,14 @@ class __TwigTemplate_ccc3f72ab858d105a4306f762fae357a extends Template
         yield from [];
     }
 
-    // line 35
+    // line 39
     /**
      * @return iterable<null|scalar|\Stringable>
      */
     public function block__content(array $context, array $blocks = []): iterable
     {
         $macros = $this->macros;
-        // line 36
+        // line 40
         yield "                    ";
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Default/output.html.twig");
         yield "
@@ -188,7 +230,7 @@ class __TwigTemplate_ccc3f72ab858d105a4306f762fae357a extends Template
      */
     public function getDebugInfo(): array
     {
-        return array (  163 => 36,  156 => 35,  146 => 61,  144 => 58,  140 => 57,  136 => 55,  122 => 43,  120 => 42,  114 => 38,  112 => 35,  102 => 28,  98 => 27,  88 => 20,  81 => 16,  75 => 13,  71 => 12,  67 => 11,  63 => 10,  59 => 9,  55 => 8,  50 => 6,  43 => 1,);
+        return array (  205 => 40,  198 => 39,  188 => 102,  186 => 99,  182 => 98,  141 => 59,  127 => 47,  125 => 46,  119 => 42,  117 => 39,  107 => 32,  103 => 31,  93 => 24,  86 => 20,  80 => 17,  76 => 16,  72 => 15,  68 => 14,  64 => 13,  60 => 12,  55 => 10,  50 => 7,  48 => 4,  47 => 3,  43 => 1,);
     }
 
     public function getSourceContext(): Source
